pub struct StablePoolParams {
pub amp: u64,
pub supports_scaling_factors_update: bool,
pub scaling_factors: Vec<AssetScalingFactor>,
pub scaling_factor_manager: Option<Addr>,
}Expand description
This struct holds stableswap pool parameters.
Fields
amp: u64The current stableswap pool amplification
supports_scaling_factors_update: boolSupport scaling factors update
scaling_factors: Vec<AssetScalingFactor>Scaling factors The scaling factor is used to scale the volume of the asset in the pool for the stableswap invariant calculations. This allows to support assets which are not equal in value but are highly correlated in price. The usecases of this are:
- Liquid staking tokens (e.g. stkATOM, stkXPRT, etc.) which differ in price to the base asset by a C-Ratio accruing the rewards earned from staking.
- Yield bearing tokens (e.g. aTokens, cTokens, etc.) which differ in price to the base asset by a C-Ratio accruing the interest earned from lending.
- Related synthetic assets which follow the price of the base assets by a defined mechanism.
scaling_factor_manager: Option<Addr>Scaling factor manager