StableSwapConfig

Struct StableSwapConfig 

pub struct StableSwapConfig {
    pub supports_scaling_factors_update: bool,
    pub scaling_factors: Vec<AssetScalingFactor>,
    pub scaling_factor_manager: Option<Addr>,
}
Stablswap config. New version removes the unused max_allowed_spread field.

Fields

supports_scaling_factors_update: bool

If this is true, then the scaling factors can be updated by the scaling_factor_manager.

scaling_factors: Vec<AssetScalingFactor>

The vector of scaling factors for each asset in the pool. The scaling factor is used to scale the volume of the asset in the pool for the stableswap invariant calculations.

scaling_factor_manager: Option<Addr>

Implementations