pub struct StableSwapConfigV1 {
pub max_allowed_spread: Decimal,
pub supports_scaling_factors_update: bool,
pub scaling_factors: Vec<AssetScalingFactor>,
pub scaling_factor_manager: Option<Addr>,
}Fields
max_allowed_spread: DecimalMax allowed spread between the price of the asset and the price of the pool. If the spread is greater than this value, the swap will fail. This value is configurable by the Pool Manager. Max allowed spread is in the range (0, 1) non-inclusive.
supports_scaling_factors_update: boolIf this is true, then the scaling factors can be updated by the scaling_factor_manager.
scaling_factors: Vec<AssetScalingFactor>The vector of scaling factors for each asset in the pool. The scaling factor is used to scale the volume of the asset in the pool for the stableswap invariant calculations.
scaling_factor_manager: Option<Addr>Trait Implementations
Sourceimpl Clone for StableSwapConfigV1
impl Clone for StableSwapConfigV1
Sourcefn clone(&self) -> StableSwapConfigV1
fn clone(&self) -> StableSwapConfigV1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StableSwapConfigV1
impl Debug for StableSwapConfigV1
Sourceimpl<'de> Deserialize<'de> for StableSwapConfigV1
impl<'de> Deserialize<'de> for StableSwapConfigV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StableSwapConfigV1
impl JsonSchema for StableSwapConfigV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StableSwapConfigV1
impl PartialEq for StableSwapConfigV1
Sourceimpl Serialize for StableSwapConfigV1
impl Serialize for StableSwapConfigV1
impl StructuralPartialEq for StableSwapConfigV1