pub struct StableSwapConfig {
pub supports_scaling_factors_update: bool,
pub scaling_factors: Vec<AssetScalingFactor>,
pub scaling_factor_manager: Option<Addr>,
}Expand description
Stablswap config. New version removes the unused max_allowed_spread field.
Fields
supports_scaling_factors_update: boolIf this is true, then the scaling factors can be updated by the scaling_factor_manager.
scaling_factors: Vec<AssetScalingFactor>The vector of scaling factors for each asset in the pool. The scaling factor is used to scale the volume of the asset in the pool for the stableswap invariant calculations.
scaling_factor_manager: Option<Addr>Implementations
Sourceimpl StableSwapConfig
impl StableSwapConfig
pub fn scaling_factors(&self) -> HashMap<AssetInfo, Decimal256>
pub fn get_scaling_factor_for( &self, asset_info: &AssetInfo, ) -> Option<Decimal256>